@@ -5,7 +5,7 @@ from vibetuner.tasks.context import lifespan
 
 
 worker = Worker(
-    redis_url=str(settings.project.redis_url),
+    redis_url=str(settings.redis_url),
     queue_name=(
         settings.project.project_slug
         if not settings.debug
